@@ -1,7 +1,5 @@
 import urllib
 
-from twisted.web.client import HTTPConnectionPool
-from twisted.internet import reactor
 from zope import interface
 import treq
 import anyjson
@@ -41,7 +39,7 @@ class HTTPConnection(object):
         self.agents = {}
         self.timeout = timeout
 
-        self.persistent = kwargs.get('persistent')
+        self.persistent = kwargs.get('persistent', True)
         self.pool = kwargs.get('pool')
 
     def close(self):
@@ -60,7 +58,7 @@ class HTTPConnection(object):
 
         def request_done(response):
             def _raise_error(body):
-                exceptions.raiseExceptions(response.code, body)
+                exceptions.raise_exceptions(response.code, body)
                 return body
 
             return treq.json_content(response.original).addCallback(
